@@ -191,7 +191,7 @@
 static const char copyright[] =
     "Copyright (c) 1996-2000\nSleepycat Software Inc.  All rights reserved.\n";
 static const char revid[] =
-    "$Id: htdb_load.cc,v 1.12 2000/07/21 14:21:24 loic Exp $";
+    "$Id: htdb_load.cc,v 1.14 2001/06/29 13:13:51 loic Exp $";
 #endif
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -205,6 +205,10 @@ static const char revid[] =
 #include <unistd.h>
 #endif
 
+#ifdef HAVE_GETOPT_H
+#include <getopt.h>
+#endif /* HAVE_GETOPT_H */
+
 extern "C" {
 #include "db_int.h"
 #include "db_page.h"
@@ -590,9 +594,10 @@ err:		rval = 1;
 	/* Free allocated memory. */
 	if (subdb != NULL)
 		free(subdb);
-	if (dbtype != DB_RECNO && dbtype != DB_QUEUE)
-		free(key.data);
-	free(data.data);
+	if (dbtype != DB_RECNO && dbtype != DB_QUEUE) {
+		if(key.data) free(key.data);
+	}
+	if(data.data) free(data.data);
 
 	return (rval);
 }
