@@ -19,7 +19,7 @@
 #include "Object.h"
 
 #include <unistd.h>
-#include <stream.h>
+//#include <stream.h>
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
