@@ -7,7 +7,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordCursorOne.cc,v 1.10 2001/06/29 14:14:08 loic Exp $
+// $Id: WordCursorOne.cc,v 1.11 2008/06/02 19:24:41 sebdiaz Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +44,7 @@ WordCursorOne::WordCursorOne(WordList *words, wordlist_walk_callback_t callback,
 }
 
 // *****************************************************************************
-WordCursorOne::WordCursorOne(WordList *words, const WordKey &searchKey, int action = HTDIG_WORDLIST_WALKER) :
+WordCursorOne::WordCursorOne(WordList *words, const WordKey &searchKey, int action) :
   WordCursor(words->GetContext()),
   prefixKey(words->GetContext())
 {
