@@ -149,8 +149,8 @@ public:
   inline int Absolute() {
     int i;
     for(i = 0; i < entries_length; i++) {
-      entries[i].key = pool + (int)(entries[i].key);
-      entries[i].data = pool + (int)(entries[i].data);
+      entries[i].key = pool + (long)(entries[i].key);
+      entries[i].data = pool + (long)(entries[i].data);
     }
     return OK;
   }
