@@ -25,7 +25,7 @@
 
 static int wordResults_cmp(const DBT* a, const DBT* b)
 {
-  int length = (int)a->app_private;
+  long length = (long)a->app_private;
 
   WordKeyNum* a_values = (WordKeyNum*)a->data;
   WordKeyNum* b_values = (WordKeyNum*)b->data;
