@@ -5,7 +5,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordSearch.cc,v 1.5 2001/08/31 14:06:04 loic Exp $
+// $Id: WordSearch.cc,v 1.6 2008/06/08 08:29:35 sebdiaz Exp $
 //
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -135,7 +135,7 @@ int WordSearch::SearchFromIndex(unsigned int length)
    * This happens when the optimization decided that the
    * expression was meaningless.
    */
-  if(expr == 0)
+  if(this==0 || expr == 0)
     return NOTOK;
 
   if(expr->Count(matches_total) != OK)
