@@ -5,7 +5,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordTree.h,v 1.9 2001/06/29 14:14:08 loic Exp $
+// $Id: WordTree.h,v 1.10 2001/07/20 10:37:53 loic Exp $
 //
 //
 // NAME
@@ -74,9 +74,10 @@
 
 class WordTreeArg {
  public:
-  WordTreeArg(WordList *words, int nuniq, int nproximity, int *document, int document_length, int location) {
+  WordTreeArg(WordList *words, int uniq, int has_uniq, int nproximity, int *document, int document_length, int location) {
     _words = words;
-    _nuniq = nuniq;
+    _uniq = uniq;
+    _has_uniq = has_uniq;
     _nproximity = nproximity;
     _document = document;
     _document_length = document_length;
@@ -85,7 +86,8 @@ class WordTreeArg {
   }
 
   WordList *_words;
-  int _nuniq;
+  int _uniq;
+  int _has_uniq;
   int _nproximity;
   int *_document;
   int _document_length;
@@ -100,7 +102,7 @@ public:
     key_semantic(words->GetContext())
   {
     proximity = 0;
-    uniq = 0;
+    has_uniq = 0;
     results = 0;
     verbose = 0;
   }
@@ -117,7 +119,7 @@ public:
   // Initialize the object. <b>words</b> is used to initialize the 
   // WordCursor base class, <b>document, document_length</b> and 
   // <b>location</b> are used to initialize the WordKeySemantic data
-  // member. The <b>nuniq</b> is the WordKey field position used by
+  // member. The <b>uniq</b> is the WordKey field position used by
   // the WordKeySemantic::DocumentNext function. The <b>nproximity</b>
   // is the proximity factor used by the WordKeySemantic::LocationCompare
   // method.
@@ -126,8 +128,8 @@ public:
   virtual int Prepare(WordTreeArg& arg) {
     int ret;
     proximity = arg._nproximity;
-    uniq = arg._nuniq;
-    if((ret = key_semantic.Initialize(arg._document, arg._document_length, arg._location, arg._nuniq)) != OK)
+    has_uniq = arg._has_uniq;
+    if((ret = key_semantic.Initialize(arg._document, arg._document_length, arg._location, arg._uniq)) != OK)
       return ret;
     key_semantic.Verbose(verbose);
     WordKey key(arg._words->GetContext());
@@ -247,9 +249,10 @@ public:
   //
   int proximity;
   //-
-  // Uniq WordKey field position. See WordKeySemantic::DocumentNext.
+  // Reduce the result set so that only one document per server 
+  // is returned. See WordKeySemantic::DocumentNext.
   //
-  int uniq;
+  int has_uniq;
   //-
   // Semantic of the WordKey object.
   //
