@@ -74,7 +74,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: mifluzsearch.cc,v 1.16 2001/07/23 13:30:33 loic Exp $
+// $Id: mifluzsearch.cc,v 1.18 2008/06/08 08:29:35 sebdiaz Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -329,9 +329,10 @@ static int dosearch(params_t* params)
     perror("start clock");
     return -1;
   }
-  
+
   WordContext* context = new WordContext();
   Configuration& config = context->GetConfiguration();
+
   if(!context) {
     fprintf(stderr, "search: cannot create context\n");
     return -1;
@@ -354,9 +355,11 @@ static int dosearch(params_t* params)
     printf("missing -B option\n");
     usage();
   }
+
   WordList *words = context->List();
   words->Open(params->dbfile, O_RDONLY);
 
+
   //
   // Return the number of occurrences of a given word
   //
@@ -385,11 +388,12 @@ static int dosearch(params_t* params)
     expr->Verbose(verbose);
   }
 
+
   //
   // Try the query parser alone
   //
   if(params->nop) {
-    printf("%s\n", (char*)expr->Get());
+    printf("%s\n", (char*)expr->Get().get());
     exit(0);
   }
 
@@ -514,11 +518,19 @@ static int dosearch(params_t* params)
     if(search->SetResults(results) != OK)
       return -1;
 
-    if(results->Open(String("Cmifluz_") +
-		     expr->search +
+	String nameFile;
+    nameFile=nameFile+String("Cmifluz_")+	expr->search +
 		     String(params->uniq_server ? "U" : "") +
 		     low_string +
-		     high_string) != OK)
+		     high_string;
+	nameFile.replace(' ', '1');
+	nameFile.replace('(', '1');
+	nameFile.replace(')', '1');
+	nameFile.replace('"', '1');
+	nameFile.replace('<', '1');
+	nameFile.replace('>', '1');
+	nameFile.replace('\t', '1');
+    if(results->Open(nameFile) != OK)
       return -1;
   }
   //
