@@ -4,12 +4,12 @@
 // word: Implement tests for the word database related classes.
 //
 // Part of the ht://Dig package   <http://www.htdig.org/>
-// Copyright (c) 1999, 2000 The ht://Dig Group
+// Copyright (c) 1999, 2000, 2001 The ht://Dig Group
 // For copyright details, see the file COPYING in your distribution
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: word.cc,v 1.43 2000/07/21 08:36:34 loic Exp $
+// $Id: word.cc,v 1.45 2001/06/29 14:14:08 loic Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -166,6 +166,8 @@ static void doword(params_t* params)
   }
 }
 
+#define DOCID_FIRST (1 | 0xf0000000)
+
 static void dolist(params_t*)
 {
   static char* word_list[] = {
@@ -198,7 +200,7 @@ static void dolist(params_t*)
     unsigned int wordid = 0;
     unsigned int location = 0;
     unsigned int anchor = 0;
-    unsigned int docid = 1;
+    unsigned int docid = DOCID_FIRST;
 
     if(verbose) fprintf(stderr, "Inserting\n");
 
@@ -220,7 +222,7 @@ static void dolist(params_t*)
     words->Close();
 
     location = anchor = 0;
-    docid = 1;
+    docid = DOCID_FIRST;
 
     if(verbose) fprintf(stderr, "Searching\n");
 
@@ -310,6 +312,7 @@ static void dolist(params_t*)
     delete result;
     delete words;
   }
+  exit(0);
   //
   // Print all records as sorted within Berkeley DB with number
   // of occurrences.
@@ -455,8 +458,6 @@ static void dolist(params_t*)
   }
 }
 
-#define WORD_BIT_MASK(b) ((b) == 32 ? 0xffffffff : (( 1 << (b)) - 1))
-
 //
 // See WordKey.h
 // Tested: Pack, Unpack, Compare (both forms), accessors, meta information
@@ -470,6 +471,7 @@ dokey(params_t* params)
     "Word 16/DocID 3/Flags 8/Location 5",
     "Word 16/DocID 3/Flags 14/Location 7",
     "Word 16/DocID 3/Flags 9/Location 7/Foo1 13/Foo2 16",
+    "Word 32/DocID 32/Flags 32/Location 32",
     0,
   };
   char** key_desc;
@@ -481,7 +483,7 @@ dokey(params_t* params)
     WordKey word(context);
     int j;
     for(j = 0; j < word.NFields(); j++) {
-      WordKeyNum value = (0xdededede & word.MaxValue(j));
+      WordKeyNum value = (0xfededede & word.MaxValue(j));
       word.Set(j, value);
     }
     if(verbose > 1) fprintf(stderr, "WORD: %s\n", (char*)word.Get());
